# This file was auto-generated by Fern from our API Definition.

import typing

import httpx
from .aio.client import AioClient, AsyncAioClient
from .browser.client import AsyncBrowserClient, BrowserClient
from .code_interpreter.client import AsyncCodeInterpreterClient, CodeInterpreterClient
from .core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from .core.request_options import RequestOptions
from .environment import SandboxEnvironment
from .raw_client import AsyncRawSandbox, RawSandbox
from .sandboxes.client import AsyncSandboxesClient, SandboxesClient
from .tokens.client import AsyncTokensClient, TokensClient
from .types.health_status import HealthStatus
from .types.limits_response import LimitsResponse


class Sandbox:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : SandboxEnvironment
        The environment to use for requests from the client. from .environment import SandboxEnvironment



        Defaults to SandboxEnvironment.PRODUCTION



    token : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.Client]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from ai_infra import Sandbox

    client = Sandbox(
        token="YOUR_TOKEN",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: SandboxEnvironment = SandboxEnvironment.PRODUCTION,
        token: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = None,
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.Client] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = SyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=token,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.Client(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.Client(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self._raw_client = RawSandbox(client_wrapper=self._client_wrapper)
        self.code_interpreter = CodeInterpreterClient(client_wrapper=self._client_wrapper, parent_client=self)
        self.browser = BrowserClient(client_wrapper=self._client_wrapper, parent_client=self)
        self.aio = AioClient(client_wrapper=self._client_wrapper, parent_client=self)
        self.sandboxes = SandboxesClient(client_wrapper=self._client_wrapper)
        self.tokens = TokensClient(client_wrapper=self._client_wrapper)

    @property
    def with_raw_response(self) -> RawSandbox:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawSandbox
        """
        return self._raw_client

    def check_health(self, *, request_options: typing.Optional[RequestOptions] = None) -> HealthStatus:
        """
        Check service health status.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HealthStatus
            Successful Response

        Examples
        --------
        from ai_infra import Sandbox

        client = Sandbox(
            token="YOUR_TOKEN",
        )
        client.check_health()
        """
        _response = self._raw_client.check_health(request_options=request_options)
        return _response.data

    def list_regions(self, *, request_options: typing.Optional[RequestOptions] = None) -> typing.Optional[typing.Any]:
        """
        List available regions for all providers.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        from ai_infra import Sandbox

        client = Sandbox(
            token="YOUR_TOKEN",
        )
        client.list_regions()
        """
        _response = self._raw_client.list_regions(request_options=request_options)
        return _response.data

    def get_limits(self, *, request_options: typing.Optional[RequestOptions] = None) -> LimitsResponse:
        """
        Get resource limits and current usage.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        LimitsResponse
            Successful Response

        Examples
        --------
        from ai_infra import Sandbox

        client = Sandbox(
            token="YOUR_TOKEN",
        )
        client.get_limits()
        """
        _response = self._raw_client.get_limits(request_options=request_options)
        return _response.data


class AsyncSandbox:
    """
    Use this class to access the different functions within the SDK. You can instantiate any number of clients with different configuration that will propagate to these functions.

    Parameters
    ----------
    base_url : typing.Optional[str]
        The base url to use for requests from the client.

    environment : SandboxEnvironment
        The environment to use for requests from the client. from .environment import SandboxEnvironment



        Defaults to SandboxEnvironment.PRODUCTION



    token : typing.Optional[typing.Union[str, typing.Callable[[], str]]]
    headers : typing.Optional[typing.Dict[str, str]]
        Additional headers to send with every request.

    timeout : typing.Optional[float]
        The timeout to be used, in seconds, for requests. By default the timeout is 60 seconds, unless a custom httpx client is used, in which case this default is not enforced.

    follow_redirects : typing.Optional[bool]
        Whether the default httpx client follows redirects or not, this is irrelevant if a custom httpx client is passed in.

    httpx_client : typing.Optional[httpx.AsyncClient]
        The httpx client to use for making requests, a preconfigured client is used by default, however this is useful should you want to pass in any custom httpx configuration.

    Examples
    --------
    from ai_infra import AsyncSandbox

    client = AsyncSandbox(
        token="YOUR_TOKEN",
    )
    """

    def __init__(
        self,
        *,
        base_url: typing.Optional[str] = None,
        environment: SandboxEnvironment = SandboxEnvironment.PRODUCTION,
        token: typing.Optional[typing.Union[str, typing.Callable[[], str]]] = None,
        headers: typing.Optional[typing.Dict[str, str]] = None,
        timeout: typing.Optional[float] = None,
        follow_redirects: typing.Optional[bool] = True,
        httpx_client: typing.Optional[httpx.AsyncClient] = None,
    ):
        _defaulted_timeout = (
            timeout if timeout is not None else 60 if httpx_client is None else httpx_client.timeout.read
        )
        self._client_wrapper = AsyncClientWrapper(
            base_url=_get_base_url(base_url=base_url, environment=environment),
            token=token,
            headers=headers,
            httpx_client=httpx_client
            if httpx_client is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout, follow_redirects=follow_redirects)
            if follow_redirects is not None
            else httpx.AsyncClient(timeout=_defaulted_timeout),
            timeout=_defaulted_timeout,
        )
        self._raw_client = AsyncRawSandbox(client_wrapper=self._client_wrapper)
        self.code_interpreter = AsyncCodeInterpreterClient(client_wrapper=self._client_wrapper, parent_client=self)
        self.browser = AsyncBrowserClient(client_wrapper=self._client_wrapper, parent_client=self)
        self.aio = AsyncAioClient(client_wrapper=self._client_wrapper, parent_client=self)
        self.sandboxes = AsyncSandboxesClient(client_wrapper=self._client_wrapper)
        self.tokens = AsyncTokensClient(client_wrapper=self._client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawSandbox:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawSandbox
        """
        return self._raw_client

    async def check_health(self, *, request_options: typing.Optional[RequestOptions] = None) -> HealthStatus:
        """
        Check service health status.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        HealthStatus
            Successful Response

        Examples
        --------
        import asyncio

        from ai_infra import AsyncSandbox

        client = AsyncSandbox(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.check_health()


        asyncio.run(main())
        """
        _response = await self._raw_client.check_health(request_options=request_options)
        return _response.data

    async def list_regions(
        self, *, request_options: typing.Optional[RequestOptions] = None
    ) -> typing.Optional[typing.Any]:
        """
        List available regions for all providers.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        typing.Optional[typing.Any]
            Successful Response

        Examples
        --------
        import asyncio

        from ai_infra import AsyncSandbox

        client = AsyncSandbox(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.list_regions()


        asyncio.run(main())
        """
        _response = await self._raw_client.list_regions(request_options=request_options)
        return _response.data

    async def get_limits(self, *, request_options: typing.Optional[RequestOptions] = None) -> LimitsResponse:
        """
        Get resource limits and current usage.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        LimitsResponse
            Successful Response

        Examples
        --------
        import asyncio

        from ai_infra import AsyncSandbox

        client = AsyncSandbox(
            token="YOUR_TOKEN",
        )


        async def main() -> None:
            await client.get_limits()


        asyncio.run(main())
        """
        _response = await self._raw_client.get_limits(request_options=request_options)
        return _response.data


def _get_base_url(*, base_url: typing.Optional[str] = None, environment: SandboxEnvironment) -> str:
    if base_url is not None:
        return base_url
    elif environment is not None:
        return environment.value
    else:
        raise Exception("Please pass in either base_url or environment to construct the client")
